@@ -1,5 +1,6 @@
 import shlex
 import re
+import argparse
 from typing import Callable
 
 
@@ -30,6 +31,20 @@ class Shrtcodes:
 
         return decorator
 
+    def create_cli(self):
+        arg_parser = argparse.ArgumentParser()
+        arg_parser.add_argument("in_file")
+        arg_parser.add_argument("--check", type=str)
+        args = arg_parser.parse_args()
+        with open(args.in_file) as f:
+            if args.check:
+                processed_text = self.process_text(f.read())
+                with open(args.check) as f2:
+                    if f2.read() != processed_text:
+                        raise exit(1)
+            else:
+                print(self.process_text(f.read()), end="")
+
     def process_text(self, text: str) -> str:
         text_stack = [""]
         shortcode_stack: list[tuple[str, list, dict]] = []
